==> owncloud-5.0.9.tgz: owncloud/apps/calendar/l10n/ms_MY.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "Tiada kalendar dijumpai.",
"No events found." => "Tiada agenda dijumpai.",
"Wrong calendar" => "Silap kalendar",
"New Timezone:" => "Timezone Baru",
"Timezone changed" => "Zon waktu diubah",
"Invalid request" => "Permintaan tidak sah",
"Calendar" => "Kalendar",
"Deletion failed" => "Pemadaman gagal",
"Editable" => "Boleh disunting",
"ddd" => "ddd",
"ddd M/d" => "dd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyy",
"Sunday" => "Ahad",
"Monday" => "Isnin",
"Tuesday" => "Selasa",
"Wednesday" => "Rabu",
"Thursday" => "Khamis",
"Friday" => "Jumaat",
"Saturday" => "Sabtu",
"Sun." => "Ahad",
"Mon." => "Isnin",
"Tue." => "Selasa",
"Wed." => "Rabu ",
"Thu." => "Khamis",
"Fri." => "Jumaat",
"Sat." => "Sabtu",
"January" => "Januari",
"February" => "Februari",
"March" => "Mac",
"April" => "April",
"May" => "Mei",
"June" => "Jun",
"July" => "Julai",
"August" => "Ogos",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "Disember",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mac.",
"Apr." => "Apr.",
"May." => "May.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Ogos.",
"Sep." => "Sept.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dis.",
"All day" => "Sepanjang hari",
"New Calendar" => "Kalendar baru",
"Title" => "Tajuk",
"From Date" => "Dari tarikh",
"From Time" => "Masa Dari",
"To Date" => "Sehingga kini",
"To Time" => "Semasa",
"The event ends before it starts" => "Peristiwa berakhir sebelum bermula",
"There was a database fail" => "Terdapat kegagalan pada pengkalan data",
"Birthday" => "Hari lahir",
"Business" => "Perniagaan",
"Call" => "Panggilan",
"Clients" => "Klien",
"Deliverer" => "Penghantar",
"Holidays" => "Cuti",
"Ideas" => "Idea",
"Journey" => "Perjalanan",
"Jubilee" => "Jubli",
"Meeting" => "Perjumpaan",
"Other" => "Lain",
"Personal" => "Peribadi",
"Projects" => "Projek",
"Questions" => "Soalan",
"Work" => "Kerja",
"unnamed" => "tiada nama",
"Does not repeat" => "Tidak berulang",
"Daily" => "Harian",
"Weekly" => "Mingguan",
"Every Weekday" => "Setiap hari minggu",
"Bi-Weekly" => "Dua kali seminggu",
"Monthly" => "Bulanan",
"Yearly" => "Tahunan",
"never" => "jangan",
"by occurrences" => "dari kekerapan",
"by date" => "dari tarikh",
"by monthday" => "dari haribulan",
"by weekday" => "dari hari minggu",
"events week of month" => "event minggu dari bulan",
"first" => "pertama",
"second" => "kedua",
"third" => "ketiga",
"fourth" => "keempat",
"fifth" => "kelima",
"last" => "akhir",
"by events date" => "dari tarikh event",
"by yearday(s)" => "dari tahun",
"by weeknumber(s)" => "dari nombor minggu",
"by day and month" => "dari hari dan bulan",
"Date" => "Tarikh",
"Cal." => "Kalendar",
"Week" => "Minggu",
"Month" => "Bulan",
"List" => "Senarai",
"Today" => "Hari ini",
"Settings" => "Tetapan",
"Your calendars" => "Kalendar anda",
"CalDav Link" => "Pautan CalDav",
"Share Calendar" => "Kongsi Kalendar",
"Download" => "Muat turun",
"Edit" => "Edit",
"Delete" => "Hapus",
"New calendar" => "Kalendar baru",
"Edit calendar" => "Edit kalendar",
"Displayname" => "Paparan nama",
"Active" => "Aktif",
"Calendar color" => "Warna kalendar",
"Save" => "Simpan",
"Submit" => "Hantar",
"Cancel" => "Batal",
"Edit an event" => "Edit agenda",
"Export" => "Export",
"Eventinfo" => "Maklumat agenda",
"Repeating" => "Pengulangan",
"Alarm" => "Penggera",
"Attendees" => "Jemputan",
"Share" => "Berkongsi",
"Title of the Event" => "Tajuk agenda",
"Category" => "kategori",
"Separate categories with commas" => "Asingkan kategori dengan koma",
"Edit categories" => "Sunting Kategori",
"All Day Event" => "Agenda di sepanjang hari ",
"From" => "Dari",
"To" => "ke",
"Advanced options" => "Pilihan maju",
"Location" => "Lokasi",
"Location of the Event" => "Lokasi agenda",
"Description" => "Huraian",
"Description of the Event" => "Huraian agenda",
"Repeat" => "Ulang",
"Advanced" => "Maju",
"Select weekdays" => "Pilih hari minggu",
"Select days" => "Pilih hari",
"and the events day of year." => "dan hari event dalam tahun.",
"and the events day of month." => "dan hari event dalam bulan.",
"Select months" => "Pilih bulan",
"Select weeks" => "Pilih minggu",
"and the events week of year." => "dan event mingguan dalam setahun.",
"Interval" => "Tempoh",
"End" => "Tamat",
"occurrences" => "Peristiwa",
"create a new calendar" => "Cipta kalendar baru",
"Import a calendar file" => "Import fail kalendar",
"Name of new calendar" => "Nama kalendar baru",
"Import" => "Import",
"Close Dialog" => "Tutup dialog",
"Create a new event" => "Buat agenda baru",
"View an event" => "Papar peristiwa",
"No categories selected" => "Tiada kategori dipilih",
"of" => "dari",
"at" => "di",
"General" => "Umum",
"Timezone" => "Zon waktu",
"24h" => "24h",
"12h" => "12h",
"more info" => "maklumat lanjut",
"Primary address (Kontact et al)" => "Alamat utama",
"iOS/OS X" => "iOS/OS X"
);

==> owncloud-7.0.4.tgz: owncloud/apps/calendar/l10n/ms_MY.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Bukan semua kalendar di-cache sepenuhnya",
"Everything seems to be completely cached" => "Semua kelihatan akan di-cache sepenuhnya",
"No calendars found." => "Tiada kalendar dijumpai.",
"No events found." => "Tiada agenda dijumpai.",
"Wrong calendar" => "Silap kalendar",
"New Timezone:" => "Timezone Baru",
"Timezone changed" => "Zon waktu diubah",
"Invalid request" => "Permintaan tidak sah",
"Calendar" => "Kalendar",
"Deletion failed" => "Pemadaman gagal",
"ddd" => "ddd",
"ddd M/d" => "dd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyy",
"Sunday" => "Ahad",
"Monday" => "Isnin",
"Tuesday" => "Selasa",
"Wednesday" => "Rabu",
"Thursday" => "Khamis",
"Friday" => "Jumaat",
"Saturday" => "Sabtu",
"Sun." => "Ahad",
"Mon." => "Isnin",
"Tue." => "Selasa",
"Wed." => "Rabu ",
"Thu." => "Khamis",
"Fri." => "Jumaat",
"Sat." => "Sabtu",
"January" => "Januari",
"February" => "Februari",
"March" => "Mac",
"April" => "April",
"May" => "Mei",
"June" => "Jun",
"July" => "Julai",
"August" => "Ogos",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "Disember",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mac.",
"Apr." => "Apr.",
"May." => "May.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Ogos.",
"Sep." => "Sept.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dis.",
"All day" => "Sepanjang hari",
"New Calendar" => "Kalendar baru",
"Title" => "Tajuk",
"From Date" => "Dari tarikh",
"From Time" => "Masa Dari",
"To Date" => "Sehingga kini",
"To Time" => "Semasa",
"The event ends before it starts" => "Peristiwa berakhir sebelum bermula",
"There was a database fail" => "Terdapat kegagalan pada pengkalan data",
"Birthday" => "Hari lahir",
"Business" => "Perniagaan",
"Call" => "Panggilan",
"Clients" => "Klien",
"Deliverer" => "Penghantar",
"Holidays" => "Cuti",
"Ideas" => "Idea",
"Journey" => "Perjalanan",
"Jubilee" => "Jubli",
"Meeting" => "Perjumpaan",
"Other" => "Lain",
"Personal" => "Peribadi",
"Projects" => "Projek",
"Questions" => "Soalan",
"Work" => "Kerja",
"by" => "oleh",
"unnamed" => "tiada nama",
"Does not repeat" => "Tidak berulang",
"Daily" => "Harian",
"Weekly" => "Mingguan",
"Every Weekday" => "Setiap hari minggu",
"Bi-Weekly" => "Dua kali seminggu",
"Monthly" => "Bulanan",
"Yearly" => "Tahunan",
"never" => "jangan",
"by occurrences" => "dari kekerapan",
"by date" => "dari tarikh",
"by monthday" => "dari haribulan",
"by weekday" => "dari hari minggu",
"events week of month" => "event minggu dari bulan",
"first" => "pertama",
"second" => "kedua",
"third" => "ketiga",
"fourth" => "keempat",
"fifth" => "kelima",
"last" => "akhir",
"by events date" => "dari tarikh event",
"by yearday(s)" => "dari tahun",
"by weeknumber(s)" => "dari nombor minggu",
"by day and month" => "dari hari dan bulan",
"Date" => "Tarikh",
"Cal." => "Kalendar",
"Week" => "Minggu",
"Month" => "Bulan",
"Today" => "Hari ini",
"CalDav Link" => "Pautan CalDav",
"Timezone" => "Zon waktu",
"24h" => "24h",
"12h" => "12h",
"Share Calendar" => "Kongsi Kalendar",
"Download" => "Muat turun",
"Edit" => "Edit",
"Delete" => "Hapus",
"New calendar" => "Kalendar baru",
"Edit calendar" => "Edit kalendar",
"Eventinfo" => "Maklumat agenda",
"Repeating" => "Pengulangan",
"Alarm" => "Penggera",
"Attendees" => "Jemputan",
"Share" => "Berkongsi",
"Title of the Event" => "Tajuk agenda",
"All Day Event" => "Agenda di sepanjang hari ",
"Advanced options" => "Pilihan maju",
"Location" => "Lokasi",
"Edit categories" => "Sunting Kategori",
"Description" => "Huraian",
"Repeat" => "Ulang",
"Advanced" => "Maju",
"Select weekdays" => "Pilih hari minggu",
"Select days" => "Pilih hari",
"and the events day of year." => "dan hari event dalam tahun.",
"and the events day of month." => "dan hari event dalam bulan.",
"Select months" => "Pilih bulan",
"Select weeks" => "Pilih minggu",
"and the events week of year." => "dan event mingguan dalam setahun.",
"Interval" => "Tempoh",
"End" => "Tamat",
"occurrences" => "Peristiwa",
"create a new calendar" => "Cipta kalendar baru",
"Import a calendar file" => "Import fail kalendar",
"Name of new calendar" => "Nama kalendar baru",
"Import" => "Import",
"Close Dialog" => "Tutup dialog",
"Create a new event" => "Buat agenda baru",
"View an event" => "Papar peristiwa",
"Category" => "kategori",
"No categories selected" => "Tiada kategori dipilih",
"From" => "Dari",
"at" => "di",
"To" => "ke"
);
